pub type AffinePoint<C> = <C as CurveArithmetic>::AffinePoint;Expand description
Affine point type for a given curve with a CurveArithmetic
implementation.
main (development) branch of crypto-glue.pub type AffinePoint<C> = <C as CurveArithmetic>::AffinePoint;Affine point type for a given curve with a CurveArithmetic
implementation.