pub type ProjectivePoint<C> = <C as CurveArithmetic>::ProjectivePoint;Expand description
Projective point type for a given curve with a CurveArithmetic
implementation.
main (development) branch of crypto-glue.pub type ProjectivePoint<C> = <C as CurveArithmetic>::ProjectivePoint;Projective point type for a given curve with a CurveArithmetic
implementation.